@@ -47,6 +47,9 @@ gtk_html_control_data_new (GtkHTML *html, GtkWidget *vbox)
 	ncd->search_text             = NULL;
 	ncd->replace_text_search     = NULL;
 	ncd->replace_text_replace    = NULL;
+	ncd->has_spell_control_set   = FALSE;
+	ncd->language                = NULL;
+	ncd->icon_theme              = gnome_icon_theme_new ();
 
 	spell_init (html, ncd);
 
@@ -76,5 +79,13 @@ gtk_html_control_data_destroy (GtkHTMLControlData *cd)
 	if (cd->gdk_painter) 
 		g_object_unref (cd->gdk_painter);
 
+	if (cd->languages)
+		CORBA_free (cd->languages);
+
+	if (cd->icon_theme) {
+		g_object_unref (cd->icon_theme);
+		cd->icon_theme = NULL;
+	}
+
 	g_free (cd);
 }
